@@ -4,8 +4,9 @@ from typing import Dict, List, Tuple
 from concurrent.futures import Future
 
 import numpy as np
+# from tensorflow.python.keras.applications.mobilenet_v2 import preprocess_input
 
-from vcap import Resize, BaseBackend, DetectionNode, deprecated
+from vcap import Resize, BaseBackend, DetectionNode
 
 _SUPPORTED_METRICS = "SUPPORTED_METRICS"
 _RANGE_FOR_ASYNC_INFER_REQUESTS = "RANGE_FOR_ASYNC_INFER_REQUESTS"
@@ -81,7 +82,7 @@ class BaseOpenVINOBackend(BaseBackend):
             return
 
         # Pull out a couple useful constants
-        self.input_blob_names: List[str] = list(self.net.inputs.keys())
+        self.input_blob_names: List[str] = list(self.net.input_info.keys())
         self.output_blob_names: List[str] = list(self.net.outputs.keys())
 
         # For running threaded requests to the network
@@ -156,13 +157,6 @@ class BaseOpenVINOBackend(BaseBackend):
                 self._num_ongoing_requests += 1
             request.async_infer(input_data)
 
-        # Add backwards compatibility for 0.2
-        future.get = future.result
-        future.get = deprecated(
-            message="Use future.result() in place of future.get()",
-            remove_in="0.3.0"
-        )(future.get)
-
         return future
 
     def prepare_inputs(self, frame: np.ndarray, frame_input_name: str = None) \
@@ -182,19 +176,21 @@ class BaseOpenVINOBackend(BaseBackend):
             inputs
         :returns: ({input_name: resized_frame}, Resize)
         """
-
-        if not frame_input_name and len(self.net.inputs) > 1:
+        if not frame_input_name and len(self.net.input_info) > 1:
             raise ValueError("More than one input was expected for model, but "
                              "default prepare_inputs implementation was used.")
 
         input_blob_name = frame_input_name or self.input_blob_names[0]
-        input_blob = self.net.inputs[input_blob_name]
+        input_data = self.net.input_info[input_blob_name].input_data
 
-        _, _, h, w = input_blob.shape
+        _, _, h, w = input_data.shape
         resize = Resize(frame).resize(w, h, Resize.ResizeType.EXACT)
 
         # Change data layout from HWC to CHW
         in_frame = np.transpose(resize.frame.copy(), (2, 0, 1))
+        # This breaks capsule backward compatibility?
+        # in_frame = np.expand_dims(in_frame, axis=0)
+        # in_frame = preprocess_input(in_frame)
 
         return {input_blob_name: in_frame}, resize
 
@@ -203,7 +199,8 @@ class BaseOpenVINOBackend(BaseBackend):
             resize: Resize,
             label_map: Dict[int, str],
             min_confidence: float = 0.0,
-            boxes_output_name: str = None) -> List[DetectionNode]:
+            boxes_output_name: str = None,
+            frame_input_name: str = None) -> List[DetectionNode]:
         """A helper method to take results from a detection-type network.
         :param results: The inference results from the network
         :param resize: A Resize object that was used to resize the image to
@@ -213,13 +210,16 @@ class BaseOpenVINOBackend(BaseBackend):
         less than this number.
         :param boxes_output_name: The name of output that carries the bounding
         box information to be parsed. Default=self.output_blob_names[0]
+        :param frame_input_name: The name of the input that took the frame in.
+
         :returns: A list of DetectionNodes, in this case representing bounding
         boxes.
         """
         output_blob_name = boxes_output_name or self.output_blob_names[0]
         inference_results = results[output_blob_name]
 
-        _, _, h, w = self.net.inputs[self.input_blob_names[0]].shape
+        input_name = frame_input_name or self.input_blob_names[0]
+        _, _, h, w = self.net.input_info[input_name].input_data.shape
 
         nodes: List[DetectionNode] = []
         for result in inference_results[0][0]:
@@ -244,7 +244,7 @@ class BaseOpenVINOBackend(BaseBackend):
             res = DetectionNode(
                 name=label_map[class_id],
                 coords=coords,
-                extra_data={"detection_confidence": confidence})
+                extra_data={"confidence": confidence})
             nodes.append(res)
 
         # Convert the coordinate space of the detections from the
